==> mongodb-7.0.18.gh.tar.gz: mongo-r7.0.18/src/mongo/s/shard_cannot_refresh_due_to_locks_held_exception.h <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include "mongo/base/error_extra_info.h"
#include "mongo/db/namespace_string.h"

namespace mongo {

class ShardCannotRefreshDueToLocksHeldInfo final : public ErrorExtraInfo {
public:
    static constexpr auto code = ErrorCodes::ShardCannotRefreshDueToLocksHeld;

    ShardCannotRefreshDueToLocksHeldInfo(NamespaceString nss) : _nss(std::move(nss)) {}

    const auto& getNss() const {
        return _nss;
    }

    void serialize(BSONObjBuilder* bob) const;

    static std::shared_ptr<const ErrorExtraInfo> parse(const BSONObj& obj);

    static ShardCannotRefreshDueToLocksHeldInfo parseFromCommandError(const BSONObj& obj);

private:
    static constexpr auto kNssFieldName = "nss"_sd;

    const NamespaceString _nss;
};

using ShardCannotRefreshDueToLocksHeldException =
    ExceptionFor<ErrorCodes::ShardCannotRefreshDueToLocksHeld>;

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/s/shard_cannot_refresh_due_to_locks_held_exception.h <==
/**
 *    Copyright (C) 2021-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>
#include <utility>

#include "mongo/base/error_codes.h"
#include "mongo/base/error_extra_info.h"
#include "mongo/base/string_data.h"
#include "mongo/bson/bsonobj.h"
#include "mongo/bson/bsonobjbuilder.h"
#include "mongo/db/namespace_string.h"
#include "mongo/util/assert_util.h"

namespace mongo {

class ShardCannotRefreshDueToLocksHeldInfo final : public ErrorExtraInfo {
public:
    static constexpr auto code = ErrorCodes::ShardCannotRefreshDueToLocksHeld;

    ShardCannotRefreshDueToLocksHeldInfo(NamespaceString nss) : _nss(std::move(nss)) {}

    const auto& getNss() const {
        return _nss;
    }

    void serialize(BSONObjBuilder* bob) const override;

    static std::shared_ptr<const ErrorExtraInfo> parse(const BSONObj& obj);

    static ShardCannotRefreshDueToLocksHeldInfo parseFromCommandError(const BSONObj& obj);

private:
    static constexpr auto kNssFieldName = "nss"_sd;

    const NamespaceString _nss;
};

using ShardCannotRefreshDueToLocksHeldException =
    ExceptionFor<ErrorCodes::ShardCannotRefreshDueToLocksHeld>;

}  // namespace mongo
